@@ -39,8 +39,12 @@
 
 #include <QTranslator>
 #include <QLocale>
-#include <QPlastiqueStyle>
 
+#if QT_VERSION < 0x050000
+#include <QPlastiqueStyle>
+#else
+#include <QStyleFactory>
+#endif
 
 #include "pinentrydialog.h"
 
@@ -218,11 +222,11 @@ main (int argc, char *argv[])
     else
       app->installTranslator(&qtTranslator);
 
-
-
+#if QT_VERSION < 0x050000
     app->setStyle(new QPlastiqueStyle());
-
-
+#else
+    app->setStyle(QStyleFactory::create("fusion"));
+#endif
 
     /* Consumes all arguments.  */
     if (pinentry_parse_opts (argc, argv))
