@@ -1,16 +1,17 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="de">
+<!DOCTYPE TS>
+<TS version="2.0" language="de">
 <context>
     <name>PinEntryDialog</name>
     <message>
-        <location filename="pinentrydialog.cpp" line="35"/>
-        <source>X2GO Pinpad</source>
-        <translation></translation>
+        <location filename="pinentrydialog.cpp" line="38"/>
+        <source>X2Go Pinpad</source>
+        <translation>X2Go PIN-Pad</translation>
     </message>
     <message>
-        <location filename="pinentrydialog.cpp" line="162"/>
+        <location filename="pinentrydialog.cpp" line="166"/>
         <source>Please, enter your PIN</source>
-        <translation type="unfinished">Geben Sie bitte Ihre PIN ein</translation>
+        <translation>Geben Sie bitte Ihre PIN ein</translation>
     </message>
 </context>
 <context>
@@ -18,7 +19,7 @@
     <message>
         <location filename="templatedlg.ui" line="13"/>
         <source>Dialog</source>
-        <translation type="unfinished"></translation>
+        <translation>Dialog</translation>
     </message>
 </context>
 </TS>
