@@ -6,12 +6,12 @@
     <message>
         <location filename="pinentrydialog.cpp" line="38"/>
         <source>X2Go Pinpad</source>
-        <translation type="unfinished"></translation>
+        <translation>Saisie de code pin X2Go</translation>
     </message>
     <message>
         <location filename="pinentrydialog.cpp" line="166"/>
         <source>Please, enter your PIN</source>
-        <translation type="unfinished"></translation>
+        <translation>Veuillez saisir votre code PIN</translation>
     </message>
 </context>
 <context>
@@ -19,7 +19,7 @@
     <message>
         <location filename="templatedlg.ui" line="13"/>
         <source>Dialog</source>
-        <translation type="unfinished"></translation>
+        <translation>Dialogue</translation>
     </message>
 </context>
 </TS>
